@@ -35,8 +35,6 @@
 
 /* local helper functions */
 
-static int nv_parse_display_and_target(char *start, char *end,
-                                       ParsedAttribute *a);
 static char **nv_strtok(char *s, char c, int *n);
 static void nv_free_strtoks(char **s, int n);
 static int ctoi(const char c);
@@ -50,33 +48,26 @@ static char *nv_strndup(char *s, int n);
  * attribute.
  */
 
-#define F NV_PARSER_TYPE_FRAMELOCK
+#define F NV_PARSER_TYPE_FRAMELOCK 
 #define C NV_PARSER_TYPE_COLOR_ATTRIBUTE
 #define N NV_PARSER_TYPE_NO_CONFIG_WRITE
 #define G NV_PARSER_TYPE_GUI_ATTRIUBUTE
 #define V NV_PARSER_TYPE_XVIDEO_ATTRIBUTE
-#define P NV_PARSER_TYPE_PACKED_ATTRIBUTE
-#define D NV_PARSER_TYPE_VALUE_IS_DISPLAY
-#define A NV_PARSER_TYPE_NO_QUERY_ALL
-#define Z NV_PARSER_TYPE_NO_ZERO_VALUE
-#define H NV_PARSER_TYPE_100Hz
 
 AttributeTableEntry attributeTable[] = {
    
     /* name                    constant                             flags */
  
+    { "FlatpanelScaling",      NV_CTRL_FLATPANEL_SCALING,           0     },
     { "FlatpanelDithering",    NV_CTRL_FLATPANEL_DITHERING,         0     },
     { "DigitalVibrance",       NV_CTRL_DIGITAL_VIBRANCE,            0     },
     { "ImageSharpening",       NV_CTRL_IMAGE_SHARPENING,            0     },
     { "BusType",               NV_CTRL_BUS_TYPE,                    0     },
-    { "BusRate",               NV_CTRL_BUS_RATE,                    0     },
     { "VideoRam",              NV_CTRL_VIDEO_RAM,                   0     },
     { "Irq",                   NV_CTRL_IRQ,                         0     },
     { "OperatingSystem",       NV_CTRL_OPERATING_SYSTEM,            0     },
     { "SyncToVBlank",          NV_CTRL_SYNC_TO_VBLANK,              0     },
     { "AllowFlipping",         NV_CTRL_FLIPPING_ALLOWED,            0     },
-    { "ForceStereoFlipping",   NV_CTRL_FORCE_STEREO,                0     },
-    { "XineramaStereoFlipping",NV_CTRL_XINERAMA_STEREO,             0     },
     { "LogAniso",              NV_CTRL_LOG_ANISO,                   0     },
     { "FSAA",                  NV_CTRL_FSAA_MODE,                   0     },
     { "TextureSharpen",        NV_CTRL_TEXTURE_SHARPEN,             0     },
@@ -86,11 +77,8 @@ AttributeTableEntry attributeTable[] = {
     { "TwinView",              NV_CTRL_TWINVIEW,                    0     },
     { "ConnectedDisplays",     NV_CTRL_CONNECTED_DISPLAYS,          0     },
     { "EnabledDisplays",       NV_CTRL_ENABLED_DISPLAYS,            0     },
-    { "AssociatedDisplays",    NV_CTRL_ASSOCIATED_DISPLAY_DEVICES,  N|D   },
-    { "ProbeDisplays",         NV_CTRL_PROBE_DISPLAYS,              A     },
     { "ForceGenericCpu",       NV_CTRL_FORCE_GENERIC_CPU,           0     },
     { "GammaCorrectedAALines", NV_CTRL_OPENGL_AA_LINE_GAMMA,        0     },
-    { "ShowSLIHUD",            NV_CTRL_SHOW_SLI_HUD,                0     },
     { "CursorShadow",          NV_CTRL_CURSOR_SHADOW,               0     },
     { "CursorShadowXOffset",   NV_CTRL_CURSOR_SHADOW_X_OFFSET,      0     },
     { "CursorShadowYOffset",   NV_CTRL_CURSOR_SHADOW_Y_OFFSET,      0     },
@@ -100,43 +88,12 @@ AttributeTableEntry attributeTable[] = {
     { "CursorShadowBlue",      NV_CTRL_CURSOR_SHADOW_BLUE,          0     },
     { "FSAAAppControlled",     NV_CTRL_FSAA_APPLICATION_CONTROLLED, 0     },
     { "LogAnisoAppControlled", NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED,0 },
-    { "RefreshRate",           NV_CTRL_REFRESH_RATE,                N|H   },
-    { "InitialPixmapPlacement",NV_CTRL_INITIAL_PIXMAP_PLACEMENT,    N     },
-    { "PCIBus",                NV_CTRL_PCI_BUS,                     N     },
-    { "PCIDevice",             NV_CTRL_PCI_DEVICE,                  N     },
-    { "PCIFunc",               NV_CTRL_PCI_FUNCTION,                N     },
-    { "DynamicTwinview",       NV_CTRL_DYNAMIC_TWINVIEW,            N     },
-    { "MultiGpuDisplayOwner",  NV_CTRL_MULTIGPU_DISPLAY_OWNER,      N     },
-    { "GPUScaling",            NV_CTRL_GPU_SCALING,                 P     },
-    { "FrontendResolution",    NV_CTRL_FRONTEND_RESOLUTION,         N|P   },
-    { "BackendResolution",     NV_CTRL_BACKEND_RESOLUTION,          N|P   },
-    { "FlatpanelNativeResolution",  NV_CTRL_FLATPANEL_NATIVE_RESOLUTION,   N|P },
-    { "FlatpanelBestFitResolution", NV_CTRL_FLATPANEL_BEST_FIT_RESOLUTION, N|P },
-    { "GPUScalingActive",      NV_CTRL_GPU_SCALING_ACTIVE,          N     },
-    { "DFPScalingActive",      NV_CTRL_DFP_SCALING_ACTIVE,          N     },
-    { "FSAAAppEnhanced",       NV_CTRL_FSAA_APPLICATION_ENHANCED,   0     },
-
-    { "FrameLockMaster",       NV_CTRL_FRAMELOCK_MASTER,            N|F|G|D },
-    { "FrameLockSlaves",       NV_CTRL_FRAMELOCK_SLAVES,            N|F|G|D },
-    { "FramelockUseHouseSync", NV_CTRL_USE_HOUSE_SYNC,              N|F|G   },
-    { "FrameLockSyncInterval", NV_CTRL_FRAMELOCK_SYNC_INTERVAL,     N|F|G   },
-    { "FrameLockPolarity",     NV_CTRL_FRAMELOCK_POLARITY,          N|F|G   },
-    { "FrameLockVideoMode",    NV_CTRL_FRAMELOCK_VIDEO_MODE,        N|F|G   },
+    { "FrameLockMaster",       NV_CTRL_FRAMELOCK_MASTER,            N|F|G },
+    { "FrameLockPolarity",     NV_CTRL_FRAMELOCK_POLARITY,          N|F|G },
     { "FrameLockSyncDelay",    NV_CTRL_FRAMELOCK_SYNC_DELAY,        N|F|G },
     { "FrameLockEnable",       NV_CTRL_FRAMELOCK_SYNC,              N|F|G },
-    { "FrameLockAvailable",    NV_CTRL_FRAMELOCK,                   N|F|G },
-    { "FrameLockPort0Status",  NV_CTRL_FRAMELOCK_PORT0_STATUS,      N|F|G },
-    { "FrameLockPort1Status",  NV_CTRL_FRAMELOCK_PORT1_STATUS,      N|F|G },
-    { "FrameLockHouseStatus",  NV_CTRL_FRAMELOCK_HOUSE_STATUS,      N|F|G },
-    { "FrameLockSyncReady",    NV_CTRL_FRAMELOCK_SYNC_READY,        N|F|G },
-    { "FrameLockStereoSync",   NV_CTRL_FRAMELOCK_STEREO_SYNC,       N|F|G },
-    { "FrameLockTestSignal",   NV_CTRL_FRAMELOCK_TEST_SIGNAL,       N|F|G },
-    { "FrameLockEthDetected",  NV_CTRL_FRAMELOCK_ETHERNET_DETECTED, N|F|G },
-    { "FrameLockSyncRate",     NV_CTRL_FRAMELOCK_SYNC_RATE,         N|F|G },
-    { "FrameLockTiming",       NV_CTRL_FRAMELOCK_TIMING,            N|F|G },
-    { "FrameLockMasterable",   NV_CTRL_FRAMELOCK_MASTERABLE,        N|F|G },
-    { "FrameLockFPGARevision", NV_CTRL_FRAMELOCK_FPGA_REVISION,     N|F|G },
-
+    { "FrameLockSyncInterval", NV_CTRL_FRAMELOCK_SYNC_INTERVAL,     N|F|G },
+    { "FrameLockHouseFormat",  NV_CTRL_FRAMELOCK_VIDEO_MODE,        N|F|G },
     { "Brightness",            BRIGHTNESS_VALUE|ALL_CHANNELS,       N|C|G },
     { "RedBrightness",         BRIGHTNESS_VALUE|RED_CHANNEL,        C|G   },
     { "GreenBrightness",       BRIGHTNESS_VALUE|GREEN_CHANNEL,      C|G   },
@@ -157,7 +114,7 @@ AttributeTableEntry attributeTable[] = {
     { "TVSaturation",          NV_CTRL_TV_SATURATION,               0     },
     { "GPUCoreTemp",           NV_CTRL_GPU_CORE_TEMPERATURE,        N     },
     { "GPUAmbientTemp",        NV_CTRL_AMBIENT_TEMPERATURE,         N     },
-    { "OpenGLImageSettings",   NV_CTRL_IMAGE_SETTINGS,              0     },
+    { "FramelockUseHouseSync", NV_CTRL_USE_HOUSE_SYNC,              0     },
 
     { "XVideoOverlaySaturation",   NV_CTRL_ATTR_XV_OVERLAY_SATURATION,     V },
     { "XVideoOverlayContrast",     NV_CTRL_ATTR_XV_OVERLAY_CONTRAST,       V },
@@ -165,14 +122,6 @@ AttributeTableEntry attributeTable[] = {
     { "XVideoOverlayHue",          NV_CTRL_ATTR_XV_OVERLAY_HUE,            V },
     { "XVideoTextureSyncToVBlank", NV_CTRL_ATTR_XV_TEXTURE_SYNC_TO_VBLANK, V },
     { "XVideoBlitterSyncToVBlank", NV_CTRL_ATTR_XV_BLITTER_SYNC_TO_VBLANK, V },
-    { "XVideoSyncToDisplay",       NV_CTRL_XV_SYNC_TO_DISPLAY,           D|Z },
-    
-    { "GPUOverclockingState",   NV_CTRL_GPU_OVERCLOCKING_STATE,     N   },
-    { "GPUDefault2DClockFreqs", NV_CTRL_GPU_DEFAULT_2D_CLOCK_FREQS, N|P },
-    { "GPUDefault3DClockFreqs", NV_CTRL_GPU_DEFAULT_3D_CLOCK_FREQS, N|P },
-    { "GPU2DClockFreqs",        NV_CTRL_GPU_2D_CLOCK_FREQS,         N|P },
-    { "GPU3DClockFreqs",        NV_CTRL_GPU_3D_CLOCK_FREQS,         N|P },
-    { "GPUCurrentClockFreqs",   NV_CTRL_GPU_CURRENT_CLOCK_FREQS,    N|P },
 
     { NULL,                    0,                                   0     }
 };
@@ -182,64 +131,6 @@ AttributeTableEntry attributeTable[] = {
 #undef N
 #undef G
 #undef V
-#undef P
-#undef D
-#undef A
-#undef Z
-#undef H
-
-/*
- * When new integer attributes are added to NVCtrl.h, an entry should
- * be added in the above attributeTable[].  The below #if should also
- * be updated to indicate the last attribute that the table knows
- * about.
- */
-
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_FSAA_APPLICATION_ENHANCED
-#warning "Have you forgotten to add a new integer attribute to attributeTable?"
-#endif
-
-
-
-/*
- * targetTypeTable[] - this table stores an association of the values
- * for each attribute target type.
- */
-
-TargetTypeEntry targetTypeTable[] = {
-
-    { "X Screen",                    /* name */
-      "screen",                      /* parsed_name */
-      X_SCREEN_TARGET,               /* target_index */
-      NV_CTRL_TARGET_TYPE_X_SCREEN,  /* nvctrl */
-      ATTRIBUTE_TYPE_X_SCREEN,       /* permission_bit */
-      NV_TRUE },                     /* uses_display_devices */
-    
-    { "GPU",                         /* name */
-      "gpu",                         /* parsed_name */
-      GPU_TARGET,                    /* target_index */
-      NV_CTRL_TARGET_TYPE_GPU,       /* nvctrl */
-      ATTRIBUTE_TYPE_GPU,            /* permission_bit */
-      NV_TRUE },                     /* uses_display_devices */
-    
-    { "Frame Lock Device",           /* name */
-      "framelock",                   /* parsed_name */
-      FRAMELOCK_TARGET,              /* target_index */
-      NV_CTRL_TARGET_TYPE_FRAMELOCK, /* nvctrl */
-      ATTRIBUTE_TYPE_FRAMELOCK,      /* permission_bit */
-      NV_FALSE },                    /* uses_display_devices */
-
-    { "VCSC",                        /* name */
-      "vcsc",                        /* parsed_name */
-      VCSC_TARGET,                   /* target_index */
-      NV_CTRL_TARGET_TYPE_VCSC,      /* nvctrl */
-      ATTRIBUTE_TYPE_VCSC,           /* permission_bit */
-      NV_FALSE },                    /* uses_display_devices */
-
-    { NULL, NULL, 0, 0, 0 },
-};
-
-
 
 /*
  * nv_parse_attribute_string() - see comments in parse.h
@@ -250,7 +141,7 @@ int nv_parse_attribute_string(const char *str, int query, ParsedAttribute *a)
     char *s, *tmp, *name, *start, *display_device_name, *no_spaces = NULL;
     char tmpname[NV_PARSER_MAX_NAME_LEN];
     AttributeTableEntry *t;
-    int len, ret;
+    int len, digits_only;
 
 #define stop(x) { if (no_spaces) free(no_spaces); return (x); }
     
@@ -274,16 +165,38 @@ int nv_parse_attribute_string(const char *str, int query, ParsedAttribute *a)
 
     /*
      * If we found a DISPLAY_NAME_SEPARATOR, and there is some text
-     * before it, parse that text as an X Display name, X screen,
-     * and/or a target specification.
+     * before it, it is either a screen number (if all characters
+     * between no_spaces and s are digits), or a display name.
      */
 
     if ((s) && (s != no_spaces)) {
         
-        ret = nv_parse_display_and_target(no_spaces, s, a);
+        /* are all characters numeric? */
 
-        if (ret != NV_PARSER_STATUS_SUCCESS) {
-            stop(ret);
+        digits_only = NV_TRUE;
+        a->screen = 0;
+        for (tmp = no_spaces; tmp != s; tmp++) {
+            if (!isdigit(*tmp)) {
+                digits_only = NV_FALSE;
+                a->screen = 0;
+            }
+            a->screen *= 10;
+            a->screen += ctoi(*tmp);
+        }
+
+        if (digits_only) {
+            a->display = NULL;
+            a->flags |= NV_PARSER_HAS_X_SCREEN;
+        } else {
+            a->display = nv_strndup(no_spaces, s - no_spaces);
+            a->flags |= NV_PARSER_HAS_X_DISPLAY;
+            
+            /*
+             * this will attempt to parse out any screen number from the
+             * display name
+             */
+            
+            nv_assign_default_display(a, NULL);
         }
     }
     
@@ -346,19 +259,9 @@ int nv_parse_attribute_string(const char *str, int query, ParsedAttribute *a)
         if (a->flags & NV_PARSER_TYPE_COLOR_ATTRIBUTE) {
             /* color attributes are floating point */
             a->fval = strtod(s, &tmp);
-        } else if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-            /*
-             * Either a single 32-bit integer or two 16-bit
-             * integers, separated by ','.
-             */
-            a->val = strtol(s, &tmp, 10);
-            if (tmp && *tmp == ',') {
-                a->val = (a->val & 0xffff) << 16;
-                a->val |= strtol((tmp + 1), &tmp, 10) & 0xffff;
-            }
         } else {
             /* all other attributes are integer */
-            a->val = strtol(s, &tmp, 0);
+            a->val = strtol(s, &tmp, 10);
         }
          
         if (tmp && (s != tmp)) a->flags |= NV_PARSER_HAS_VAL;
@@ -377,188 +280,6 @@ int nv_parse_attribute_string(const char *str, int query, ParsedAttribute *a)
 
 
 
-/*
- * nv_parse_display_and_target() - helper function for
- * nv_parse_attribute_string() to parse all the text before the
- * DISPLAY_NAME_SEPARATOR.  This text is expected to be an X Display
- * name, just an X screen, and/or a target specification.
- */
-
-static int nv_parse_display_and_target(char *start,
-                                       char *end, /* exclusive */
-                                       ParsedAttribute *a)
-{
-    int digits_only, i, target_type, target_id, len;
-    char *tmp, *s, *pOpen, *pClose, *colon;
-
-    /*
-     * are all characters numeric? compute the target_id integer as we
-     * scan the string to check
-     */
-    
-    digits_only = NV_TRUE;
-    target_id = 0;
-    
-    for (s = start; s < end; s++) {
-        if (!isdigit(*s)) {
-            digits_only = NV_FALSE;
-            break;
-        }
-        target_id = (target_id * 10) + ctoi(*s);
-    }
-
-    /*
-     * if all characters are numeric, assume the target type is
-     * X_SCREEN, and build the target_id; we have no X Display name in
-     * this case.
-     */
-    
-    if (digits_only) {
-        a->display = NULL;
-        a->flags &= ~NV_PARSER_HAS_X_DISPLAY;
-        a->flags |= NV_PARSER_HAS_TARGET;
-        a->target_id = target_id;
-        a->target_type = NV_CTRL_TARGET_TYPE_X_SCREEN;
-        
-        /* we are done */
-        
-        return NV_PARSER_STATUS_SUCCESS;
-    }
-    
-    /*
-     * if we get here, then there are non-digit characters; look for a
-     * pair of brackets, and treat the contents as a target
-     * specification.
-     */
-    
-    pOpen = pClose = NULL;
-
-    for (s = start; s < end; s++) {
-        if (*s == '[') pOpen = s;
-        if (*s == ']') pClose = s;
-    }
-
-    if (pOpen && pClose && (pClose > pOpen) && ((pClose - pOpen) > 1)) {
-
-        /*
-         * we have a pair of brackets and something inside the
-         * brackets, pull that into a temporary string.
-         */
-
-        len = pClose - pOpen - 1;
-
-        tmp = nv_strndup(pOpen + 1, len);
-
-        /* find the colon within the temp string */
-
-        colon = strchr(tmp, ':');
-        
-        /* no colon? give up */
-
-        if (!colon) {
-            free(tmp);
-            return NV_PARSER_STATUS_TARGET_SPEC_NO_COLON;
-        }
-        
-        /*
-         * check that what is between the opening bracket and the
-         * colon is a target type name
-         */
-
-        *colon = '\0';
-        target_type = -1;
-
-        for (i = 0; targetTypeTable[i].name; i++) {
-            if (nv_strcasecmp(tmp, targetTypeTable[i].parsed_name)) {
-                target_type = targetTypeTable[i].nvctrl;
-                break;
-            }
-        }
-        
-        *colon = ':';
-        
-        /* if we did not find a matching target name, give up */
-        
-        if (target_type == -1) {
-            free(tmp);
-            return NV_PARSER_STATUS_TARGET_SPEC_BAD_TARGET;
-        }
-        
-        /*
-         * check that we have something between the colon and the end
-         * of the temp string
-         */
-
-        if ((colon + 1 - tmp) >= len) {
-            free(tmp);
-            return NV_PARSER_STATUS_TARGET_SPEC_NO_TARGET_ID;
-        }
-
-        /*
-         * everything after the colon should be numeric; assign it to
-         * the target_id
-         */
-        
-        target_id = 0;
-
-        for (s = colon + 1; *s; s++) {
-            if (!isdigit(*s)) {
-                free(tmp);
-                return NV_PARSER_STATUS_TARGET_SPEC_BAD_TARGET_ID;
-            }
-            target_id = (target_id * 10) + ctoi(*s);
-        }
-        
-        a->target_type = target_type;
-        a->target_id = target_id;
-        
-        a->flags |= NV_PARSER_HAS_TARGET;
-
-        /* we're finally done with the temp string */
-
-        free(tmp);
-        
-        /*
-         * check that there is no stray text between the closing
-         * bracket and the end of our parsable string
-         */
-
-        if ((end - pClose) > 1) {
-            return NV_PARSER_STATUS_TARGET_SPEC_TRAILING_GARBAGE;
-        }
-        
-        /*
-         * make end now point at the start of the bracketed target
-         * info for the X Display name processing below
-         */
-        
-        end = pOpen;
-    }
-    
-
-    /* treat everything between start and end as an X Display name */
-    
-    if (start < end) {
-
-        a->display = nv_strndup(start, end - start);
-        a->flags |= NV_PARSER_HAS_X_DISPLAY;
-            
-        /*
-         * this will attempt to parse out any screen number from the
-         * display name
-         */
-    
-        nv_assign_default_display(a, NULL);
-    }
-    
-    /* done */
-
-    return NV_PARSER_STATUS_SUCCESS;
-    
-} /* nv_parse_display_and_target() */
-
-
-
 /*
  * nv_parse_strerror() - given the error status returned by
  * nv_parse_attribute_string(), return a string describing the
@@ -588,19 +309,6 @@ char *nv_parse_strerror(int status)
         return "Trailing garbage"; break;
     case NV_PARSER_STATUS_UNKNOWN_ATTR_NAME :
         return "Unrecognized attribute name"; break;
-    case NV_PARSER_STATUS_MISSING_COMMA:
-        return "Missing comma in packed integer value"; break;
-    case NV_PARSER_STATUS_TARGET_SPEC_NO_COLON:
-        return "No colon in target specification"; break;
-    case NV_PARSER_STATUS_TARGET_SPEC_BAD_TARGET:
-        return "Bad target in target specification"; break;
-    case NV_PARSER_STATUS_TARGET_SPEC_NO_TARGET_ID:
-        return "No target ID in target specification"; break;
-    case NV_PARSER_STATUS_TARGET_SPEC_BAD_TARGET_ID:
-        return "Bad target ID in target specification"; break;
-    case NV_PARSER_STATUS_TARGET_SPEC_TRAILING_GARBAGE:
-        return "Trailing garbage after target specification"; break;
-        
     default:
         return "Unknown error"; break;
     }
@@ -735,8 +443,9 @@ uint32 display_device_name_to_display_device_mask(const char *str)
 /*
  * display_device_mask_to_display_name() - construct a string
  * describing the given display device mask.  The returned pointer
- * points to a newly allocated string, so callers to this function
- * are responsible for freeing the memory.
+ * points to a global character buffer, so subsequent calls to
+ * display_device_mask_to_display_device_name() will clobber the
+ * contents.
  */
 
 #define DISPLAY_DEVICE_STRING_LEN 256
@@ -844,7 +553,6 @@ uint32 expand_display_device_mask_wildcards(const uint32 d, const uint32 e)
 void nv_assign_default_display(ParsedAttribute *a, const char *display)
 {
     char *colon, *dot, *s;
-    int digits_only;
 
     if (!(a->flags & NV_PARSER_HAS_X_DISPLAY)) {
         if (display) a->display = strdup(display);
@@ -852,33 +560,18 @@ void nv_assign_default_display(ParsedAttribute *a, const char *display)
         a->flags |= NV_PARSER_HAS_X_DISPLAY;
     }
 
-    if (!(a->flags & NV_PARSER_HAS_TARGET) && a->display) {
+    if (!(a->flags & NV_PARSER_HAS_X_SCREEN) && a->display) {
         colon = strchr(a->display, ':');
         if (colon) {
             dot = strchr(colon, '.');
             if (dot) {
-                
-                /*
-                 * if all characters afer the '.' are digits,
-                 * interpret it as a screen number.
-                 */
-
-                digits_only = NV_FALSE;
-                a->target_id = 0;
-
-                for (s = dot + 1; *s; s++) {
-                    if (isdigit(*s)) {
-                        digits_only = NV_TRUE;
-                        a->target_id = (a->target_id * 10) + ctoi(*s);
-                    } else {
-                        digits_only = NV_FALSE;
-                        break;
-                    }
-                }
-
-                if (digits_only) {
-                    a->target_type = NV_CTRL_TARGET_TYPE_X_SCREEN;
-                    a->flags |= NV_PARSER_HAS_TARGET;
+                a->screen = 0;
+                s = dot + 1;
+                while (*s && isdigit(*s)) {
+                    a->screen *= 10;
+                    a->screen += ctoi(*s);
+                    a->flags |= NV_PARSER_HAS_X_SCREEN;
+                    s++;
                 }
             }
         }
@@ -924,8 +617,7 @@ void nv_parsed_attribute_add(ParsedAttribute *head, ParsedAttribute *a)
     if (a->display) t->display = strdup(a->display);
     else t->display = NULL;
     
-    t->target_type         = a->target_type;
-    t->target_id           = a->target_id;
+    t->screen              = a->screen;
     t->attr                = a->attr;
     t->val                 = a->val;
     t->fval                = a->fval;
@@ -991,15 +683,6 @@ char *nv_get_attribute_name(const int attr)
 } /* nv_get_attribute_name() */
 
 
-
-/*
- * nv_standardize_screen_name() - standardize the X Display name, by
- * inserting the hostname (if necessary), and using the specified
- * screen number.  If 'screen' is -1, use the screen number already in
- * the string.  If 'screen' is -2, do not put a screen number in the
- * Display name.
- */
-
 char *nv_standardize_screen_name(const char *orig, int screen)
 {
     char *display_name, *screen_name, *colon, *dot, *tmp;
@@ -1058,24 +741,15 @@ char *nv_standardize_screen_name(const char *orig, int screen)
     
     dot = strchr(colon, '.');
     if (dot) *dot = '\0';
-
-    /*
-     * if the screen parameter is -2, then do not write out a screen
-     * number.
-     */
     
-    if (screen == -2) {
-        screen_name = display_name;
-    } else {
-        len = strlen(display_name) + 8;
-        screen_name = malloc(len);
-        snprintf(screen_name, len, "%s.%d", display_name, screen);
-        free(display_name);
-    }
+    len = strlen(display_name) + 8;
+    screen_name = malloc(len);
+    snprintf(screen_name, len, "%s.%d", display_name, screen);
+    
+    free(display_name);
     
     return (screen_name);
-
-} /* nv_standardize_screen_name() */
+}
 
 
 
